<!DOCTYPE html>
<html{% block html_attrs  %}{% endblock html_attrs %}>
{% block html %}
  <head>
    {% block head %}
    <title>{% block title %}{{title|default}}{% endblock title %}</title>

    {% block metas %}
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    {% endblock metas %}

    {% block css %}
    {% endblock css %}
    
    {% endblock head %}
  </head>
  <body{% block body_attrs %}{% endblock body_attrs %}>
    {% block body %}
    
    <div id="app">  
      {% block content %}
      {% endblock content %}
    </div>

    {% block scripts %}
      <script src="{{ url_for('static', filename='js/main.js') }}"></script>
    {% endblock scripts %}
  
    {% endblock body %}
  </body>
{% endblock html %}
</html>
